@@ -54,7 +54,8 @@ public class StandardizeFiles
     PixmapWriter writer = new PixmapWriter();
     writer.SetFileName( outfilename );
     writer.SetFile( reader.GetFile() );
-    gdcm.Pixmap pixout = ((PixmapToPixmapFilter)change).GetOutput();
+    gdcm.Bitmap bitout = change.GetOutput();
+    gdcm.Pixmap pixout = (gdcm.Pixmap)bitout;
     //System.Console.WriteLine( "Debug: " + pixout.toString() );
 
     writer.SetPixmap( pixout );
