@@ -1,9 +1,8 @@
 /*=========================================================================
 
   Program: GDCM (Grassroots DICOM). A DICOM library
-  Module:  $URL$
 
-  Copyright (c) 2006-2010 Mathieu Malaterre
+  Copyright (c) 2006-2011 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -111,7 +110,7 @@ int main(int argc, char *argv[])
 
       for( int index = 1; it != mapping.end(); ++it, ++index)
         {
-        const Tag & tag = it->first;
+        //const Tag & tag = it->first;
         const char *value = it->second;
 
         if (sqlite3_bind_text (
