@@ -21,8 +21,19 @@
 #include <iostream>
 #include <string>
 
+#include <map>
+
+/*
+ * This example will extract the Movie from the private group of
+ * GEMS_Ultrasound_MovieGroup_001 See Attribute
+ * (7fe1,60,GEMS_Ultrasound_MovieGroup_001)
+ *
+ * The output file will be stored in `outvid.dcm` as
+ * MultiframeGrayscaleByteSecondaryCaptureImageStorage
+ */
 int main(int argc, char *argv[])
 {
+  if( argc < 2 ) return 1;
   using namespace gdcm;
   const char *filename = argv[1];
   gdcm::Reader reader;
@@ -48,83 +59,118 @@ int main(int argc, char *argv[])
 
   SmartPointer<SequenceOfItems> sqi2 = seq1.GetValueAsSQ();
   //int n = sqi2->GetNumberOfItems();
-//std::cout << n << std::endl;
-int i = 1;
-//  for( int i = 1; i <= n; ++i )
-    Item &item2 = sqi2->GetItem(i);
-    DataSet &subds2 = item2.GetNestedDataSet();
+  int index = 1;
+  Item &item2 = sqi2->GetItem(index);
+  DataSet &subds2 = item2.GetNestedDataSet();
 
-    const PrivateTag tseq2(0x7fe1,0x20,"GEMS_Ultrasound_MovieGroup_001");
+  const PrivateTag tseq2(0x7fe1,0x20,"GEMS_Ultrasound_MovieGroup_001");
 
-    if( !subds2.FindDataElement( tseq2 ) ) return 1;
-    const DataElement& seq2 = subds2.GetDataElement( tseq2 );
+  if( !subds2.FindDataElement( tseq2 ) ) return 1;
+  const DataElement& seq2 = subds2.GetDataElement( tseq2 );
 
 //    std::cout << seq2 << std::endl;
 
   SmartPointer<SequenceOfItems> sqi3 = seq2.GetValueAsSQ();
-  //int ni3= sqi3->GetNumberOfItems();
+  int ni3 = sqi3->GetNumberOfItems();
   assert( sqi3->GetNumberOfItems() >= 1 );
   Item &item3 = sqi3->GetItem(1);
   DataSet &subds3 = item3.GetNestedDataSet();
 
-  const PrivateTag tseq3(0x7fe1,0x36,"GEMS_Ultrasound_MovieGroup_001");
+  const PrivateTag tseq6(0x7fe1,0x26,"GEMS_Ultrasound_MovieGroup_001");
+  if( !subds3.FindDataElement( tseq6 ) ) return 1;
+  const DataElement& seq6 = subds3.GetDataElement( tseq6 );
+  SmartPointer<SequenceOfItems> sqi6 = seq6.GetValueAsSQ();
+  int ni6= sqi6->GetNumberOfItems();
+  assert( sqi6->GetNumberOfItems() >= 1 );
+  const PrivateTag tseq7(0x7fe1,0x86,"GEMS_Ultrasound_MovieGroup_001");
+  int dimx, dimy;
+  for( int i6 = 1; i6 <= ni6; ++i6 )
+    {
+    Item &item6 = sqi6->GetItem(i6);
+    DataSet &subds6 = item6.GetNestedDataSet();
 
+    if( subds6.FindDataElement( tseq7 ) )
+      {
+      Element<VR::SL, VM::VM4> el;
+      el.SetFromDataElement( subds6.GetDataElement( tseq7 ) );
+      std::cout << "El= " << el.GetValue() << std::endl;
+      dimx = el.GetValue(0);
+      dimy = el.GetValue(1);
+      }
+    }
+
+  const PrivateTag tseq3(0x7fe1,0x36,"GEMS_Ultrasound_MovieGroup_001");
   if( !subds3.FindDataElement( tseq3 ) ) return 1;
   const DataElement& seq3 = subds3.GetDataElement( tseq3 );
 
-    std::cout << seq3 << std::endl;
+//    std::cout << seq3 << std::endl;
 
   SmartPointer<SequenceOfItems> sqi4 = seq3.GetValueAsSQ();
-  //int ni4= sqi4->GetNumberOfItems();
+  int ni4= sqi4->GetNumberOfItems();
   assert( sqi4->GetNumberOfItems() >= 1 );
-  Item &item4 = sqi4->GetItem(1);
-  DataSet &subds4 = item4.GetNestedDataSet();
-
+  const PrivateTag tseq8(0x7fe1,0x37,"GEMS_Ultrasound_MovieGroup_001");
   const PrivateTag tseq4(0x7fe1,0x43,"GEMS_Ultrasound_MovieGroup_001");
   const PrivateTag tseq5(0x7fe1,0x60,"GEMS_Ultrasound_MovieGroup_001");
 
-  if( !subds4.FindDataElement( tseq4 ) ) return 1;
-  const DataElement& seq4 = subds4.GetDataElement( tseq4 );
-  if( !subds4.FindDataElement( tseq5 ) ) return 1;
-  const DataElement& seq5 = subds4.GetDataElement( tseq5 );
+  std::vector<char> imbuffer;
+  int dimz = 0;
+  for( int i4 = 1; i4 <= ni4; ++i4 )
+    {
+    Item &item4 = sqi4->GetItem(i4);
+    DataSet &subds4 = item4.GetNestedDataSet();
 
-    std::cout << seq4 << std::endl;
-    std::cout << seq5 << std::endl;
+    if( !subds4.FindDataElement( tseq8 ) ) return 1;
+    const DataElement& de8 = subds4.GetDataElement( tseq8 );
+    Element<VR::UL,VM::VM1> ldimz;
+    ldimz.SetFromDataElement( de8 );
+    dimz += ldimz.GetValue();
+    if( !subds4.FindDataElement( tseq4 ) ) return 1;
+    const DataElement& seq4 = subds4.GetDataElement( tseq4 );
+    if( !subds4.FindDataElement( tseq5 ) ) return 1;
+    const DataElement& seq5 = subds4.GetDataElement( tseq5 );
 
-  const ByteValue *bv4 = seq4.GetByteValue();
-{
-  std::ofstream out( "/tmp/mo4" );
-  out.write( bv4->GetPointer(), bv4->GetLength());
-  out.close();
-}
+    //    std::cout << seq4 << std::endl;
+    //    std::cout << seq5 << std::endl;
 
+    const ByteValue *bv4 = seq4.GetByteValue();
+#if 0
+      {
+      std::ofstream out( "/tmp/mo4" );
+      out.write( bv4->GetPointer(), bv4->GetLength());
+      out.close();
+      }
+#endif
   const ByteValue *bv5 = seq5.GetByteValue();
-{
-  std::ofstream out( "/tmp/mo5" );
-  out.write( bv5->GetPointer(), bv5->GetLength());
-  out.close();
-}
+#if 0
+    {
+    std::ofstream out( "/tmp/mo5" );
+    out.write( bv5->GetPointer(), bv5->GetLength());
+    out.close();
+    }
+#endif
+
+    std::cout << bv5->GetLength() << std::endl;
+    imbuffer.insert( imbuffer.begin(), bv5->GetPointer(), bv5->GetPointer() + bv5->GetLength() );
+    }
+  DataElement fakedata;
+  fakedata.SetByteValue( &imbuffer[0], imbuffer.size() );
+
 
   gdcm::SmartPointer<gdcm::Image> im = new gdcm::Image;
   im->SetNumberOfDimensions( 3 );
-  // (7fe1,1086) SL 440\129\0\2                              #  16, 4 Unknown Tag & Data
 
-  im->SetDimension(0, 440 );
-  im->SetDimension(0, 923 );
-  im->SetDimension(1, 129 );
-  im->SetDimension(1, 189 );
-  im->SetDimension(2, 800 );
-  im->SetDimension(2, 1 );
+  im->SetDimension(0, dimx );
+  im->SetDimension(1, dimy );
+  im->SetDimension(2, dimz );
+  size_t l1 = imbuffer.size();
+  size_t l2 = im->GetBufferLength();
+  assert( im->GetBufferLength() == imbuffer.size() );
   im->SetPhotometricInterpretation( gdcm::PhotometricInterpretation::MONOCHROME2 );
 
-//  gdcm::DataElement pixeldata( gdcm::Tag(0x7fe0,0x0010) );
-//  pixeldata.SetByteValue( bv5->GetPointer(), l );
-//  im->SetDataElement( pixeldata );
-  im->SetDataElement( seq5 );
+  im->SetDataElement( fakedata );
 
   gdcm::ImageWriter w;
   w.SetImage( *im );
-//  w.SetFile( fd.GetFile() );
   DataSet &dataset = w.GetFile().GetDataSet();
 
   gdcm::UIDGenerator uid;
