@@ -403,6 +403,9 @@ static const LossyFile gdcmLossyFilenames[] = {
 { 0, "GDCMJ2K_TextGBR.dcm" },
 { 0, "PhilipsInteraSeqTermInvLen.dcm" },
 { 0, "LIBIDO-24-ACR_NEMA-Rectangle.dcm" },
+{ 0, "TOSHIBA_J2K_SIZ1_PixRep0.dcm" },
+{ 0, "TOSHIBA_J2K_SIZ0_PixRep1.dcm" },
+{ 0, "TOSHIBA_J2K_OpenJPEGv2Regression.dcm" },
 { 0, NULL }
 };
 
@@ -457,7 +460,7 @@ const wchar_t *Testing::GetTempDirectoryW(const wchar_t * subdir)
 {
   static std::wstring buffer;
   wchar_t wname[4096]; // FIXME
-  size_t len = mbstowcs(wname,GDCM_TEMP_DIRECTORY,sizeof(wname));
+  size_t len = mbstowcs(wname,GDCM_TEMP_DIRECTORY,sizeof(wname)/sizeof(wchar_t));
   (void)len;
   if( !subdir )
     {
