@@ -1,9 +1,8 @@
 /*=========================================================================
 
   Program: GDCM (Grassroots DICOM). A DICOM library
-  Module:  $URL$
 
-  Copyright (c) 2006-2010 Mathieu Malaterre
+  Copyright (c) 2006-2011 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -14,6 +13,8 @@
 =========================================================================*/
 #include "gdcmByteValue.h"
 
+#include <cstring> // memcpy
+
 namespace gdcm
 {
 
@@ -28,7 +29,7 @@ namespace gdcm
         }
       }
     // I cannot check IsPrintable some file contains \2 or \0 in a VR::LO element
-    // See: acr_image_with_non_printable_in_0051_1010.acr 
+    // See: acr_image_with_non_printable_in_0051_1010.acr
     //assert( IsPrintable(length) );
     std::vector<char>::const_iterator it = Internal.begin();
     for(; it != Internal.begin()+length; ++it)
@@ -55,4 +56,16 @@ namespace gdcm
     os << std::dec;
   }
 
+  bool ByteValue::GetBuffer(char *buffer, unsigned long length) const {
+    // SIEMENS_GBS_III-16-ACR_NEMA_1.acr has a weird pixel length
+    // so we need an inequality
+    if( length <= Internal.size() )
+      {
+      memcpy(buffer, &Internal[0], length);
+      return true;
+      }
+    gdcmDebugMacro( "Could not handle length= " << length );
+    return false;
+    }
+
 }
