@@ -1,9 +1,8 @@
 /*=========================================================================
 
   Program: GDCM (Grassroots DICOM). A DICOM library
-  Module:  $URL$
 
-  Copyright (c) 2006-2010 Mathieu Malaterre
+  Copyright (c) 2006-2011 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -76,6 +75,7 @@ public:
     JPEGLSNearLossless,
     JPEG2000Lossless,
     JPEG2000,
+    JPIPReferenced,
     RLELossless,
     MPEG2MainProfile,
     ImplicitVRBigEndianACRNEMA,
