@@ -1,9 +1,8 @@
 /*=========================================================================
 
   Program: GDCM (Grassroots DICOM). A DICOM library
-  Module:  $URL$
 
-  Copyright (c) 2006-2010 Mathieu Malaterre
+  Copyright (c) 2006-2011 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -20,7 +19,7 @@
 
 namespace gdcm
 {
-  
+
 class CurveInternal;
 class ByteValue;
 class DataSet;
@@ -63,6 +62,10 @@ public:
   void SetCurveDescription(const char *curvedescription);
   void SetDataValueRepresentation(unsigned short datavaluerepresentation);
   unsigned short GetDataValueRepresentation() const;
+  void SetCurveDataDescriptor(const uint16_t * values, size_t num);
+  void SetCoordinateStartValue( unsigned short v );
+  void SetCoordinateStepValue( unsigned short v );
+
   void SetCurve(const char *array, unsigned int length);
 
   bool IsEmpty() const;
@@ -71,6 +74,7 @@ public:
 
   Curve(Curve const &ov);
 private:
+  double ComputeValueFromStartAndStep(unsigned int idx) const;
   CurveInternal *Internal;
 };
 
