@@ -99,88 +99,6 @@ Overlay::Overlay(Overlay const &ov):Object(ov)
   *Internal = *ov.Internal;
 }
 
-unsigned int Overlay::GetNumberOfOverlays(DataSet const & ds)
-{
-  Tag overlay(0x6000,0x0000); // First possible overlay
-  bool finished = false;
-  unsigned int numoverlays = 0;
-  while( !finished )
-    {
-    const DataElement &de = ds.FindNextDataElement( overlay );
-    if( de.GetTag().GetGroup() > 0x60FF ) // last possible curve
-      {
-      finished = true;
-      }
-    else if( de.GetTag().IsPrivate() )
-      {
-      // Move on to the next public one:
-      overlay.SetGroup( de.GetTag().GetGroup() + 1 );
-      overlay.SetElement( 0 ); // reset just in case...
-      }
-    else
-      {
-      // Yeah this is a potential overlay element, let's check this is not a broken LEADTOOL image,
-      // or prova0001.dcm:
-      // (5000,0000) UL 0                                        #   4, 1 GenericGroupLength
-      // (6000,0000) UL 0                                        #   4, 1 GenericGroupLength
-      // (6001,0000) UL 28                                       #   4, 1 PrivateGroupLength
-      // (6001,0010) LT [PAPYRUS 3.0]                            #  12, 1 PrivateCreator
-      // (6001,1001) LT (no value available)                     #   0, 0 Unknown Tag & Data
-/*
- * FIXME:
- * In order to support : gdcmData/SIEMENS_GBS_III-16-ACR_NEMA_1.acr
- *                       gdcmDataExtra/gdcmSampleData/images_of_interest/XA_GE_JPEG_02_with_Overlays.dcm
- * I cannot simply check for overlay_group,3000 this would not work
- * I would need a strong euristick
- */
-      // Store found tag in overlay:
-      overlay = de.GetTag();
-      // heuristic based on either the Overlay Data or the Col/Row info
-      Tag toverlaydata(overlay.GetGroup(),0x3000 );
-      Tag toverlayrows(overlay.GetGroup(),0x0010 );
-      Tag toverlaycols(overlay.GetGroup(),0x0011 );
-      Tag toverlaybitpos(overlay.GetGroup(),0x0102 );
-      if( ds.FindDataElement( toverlaydata ) )
-        {
-        // ok so far so good...
-        const DataElement& overlaydata = ds.GetDataElement( toverlaydata );
-        //const DataElement& overlaydata = ds.GetDataElement(Tag(overlay.GetGroup(),0x0010));
-        if( !overlaydata.IsEmpty() )
-          {
-          ++numoverlays;
-          }
-        }
-      else if( ds.FindDataElement( toverlayrows ) && ds.FindDataElement( toverlaycols )
-        && ds.FindDataElement( toverlaybitpos ) )
-        {
-        // Overlay Pixel are in Unused Pixel
-        assert( !ds.FindDataElement( toverlaydata ) );
-        const DataElement& overlayrows = ds.GetDataElement( toverlayrows );
-        const DataElement& overlaycols = ds.GetDataElement( toverlaycols );
-        assert( ds.FindDataElement( toverlaybitpos ) );
-        const DataElement& overlaybitpos = ds.GetDataElement( toverlaybitpos );
-        if( !overlayrows.IsEmpty() && !overlaycols.IsEmpty() && !overlaybitpos.IsEmpty() )
-          {
-          ++numoverlays;
-          }
-        }
-        // Move on to the next possible one:
-        overlay.SetGroup( overlay.GetGroup() + 2 );
-        // reset to element 0x0 just in case...
-        overlay.SetElement( 0 );
-      }
-    }
-
-  // at most one out of two :
-  assert( numoverlays < 0x00ff / 2 );
-  // PS 3.3 - 2004:
-  // C.9.2 Overlay plane module
-  // Each Overlay Plane is one bit deep. Sixteen separate Overlay Planes may be associated with an
-  // Image or exist as Standalone Overlays in a Series
-  assert( numoverlays <= 16 );
-  return numoverlays;
-}
-
 void Overlay::Update(const DataElement & de)
 {
 /*
