@@ -1,9 +1,8 @@
 /*=========================================================================
 
   Program: GDCM (Grassroots DICOM). A DICOM library
-  Module:  $URL$
 
-  Copyright (c) 2006-2010 Mathieu Malaterre
+  Copyright (c) 2006-2011 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -20,14 +19,14 @@
 
 namespace gdcm
 {
-  
+
 class OverlayInternal;
 class ByteValue;
 class DataSet;
 class DataElement;
 /**
  * \brief Overlay class
- * \note 
+ * \note
  * see AreOverlaysInPixelData
  *
  * \todo
@@ -44,10 +43,6 @@ public:
   /// Print
   void Print(std::ostream &) const;
 
-  /// Will traverse the dataset in search for overlay elements
-  /// this is an hybrid method I don't like having it attach to an Overlay object
-  static unsigned int GetNumberOfOverlays(DataSet const & ds);
-
   /// Update overlay from data element de:
   void Update(const DataElement & de);
 
