@@ -1,9 +1,8 @@
 /*=========================================================================
 
   Program: GDCM (Grassroots DICOM). A DICOM library
-  Module:  $URL$
 
-  Copyright (c) 2006-2010 Mathieu Malaterre
+  Copyright (c) 2006-2011 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -120,7 +119,7 @@ bool StringFilter::ExecuteQuery(std::string const & query_const,
   char *saveptr1, *saveptr2;
   int j;
 
-  bool dicomnativemodel = false;
+  //bool dicomnativemodel = false;//unused
   const gdcm::DataSet *curds = NULL;
   const gdcm::DataElement *curde = NULL;
   gdcm::Tag t;
@@ -157,8 +156,8 @@ bool StringFilter::ExecuteQuery(std::string const & query_const,
         break;
         }
       assert( subtokens[1] == "keyword" );
-      const char *k = subtokens[2].c_str();
-      const gdcm::DictEntry &dictentry = pubdict.GetDictEntryByKeyword(k, t);
+      //const char *k = subtokens[2].c_str();//unused
+      //const gdcm::DictEntry &dictentry = pubdict.GetDictEntryByKeyword(k, t);//unused
       if( !curds->FindDataElement( t ) )
         {
         state = -1;
