@@ -91,6 +91,70 @@ blacklist = (
 "Coder"
 "ImageChangePhotometricInterpretation"
 "IconImage" # FIXME
+"StreamImageReader"
+"StreamImageWriter"
+"IconImageFilter"
+"IconImageGenerator"
+"DirectoryHelper"
+"DataEvent"
+"DataSetEvent"
+# MEXD
+"ApplicationContext"
+"AAssociateRJPDU"
+"AAssociateACPDU"
+"ULBasicCallback"
+"ULActionDT"
+"ULActionAA"
+"QueryPatient"
+"ULActionAE"
+"ImplementationVersionNameSub"
+"NetworkStateID"
+"AReleaseRQPDU"
+"MoveStudyRootQuery"
+"ULConnectionCallback"
+"NetworkEvents"
+"QueryImage"
+"ULEvent"
+"PresentationContextRQ"
+"PDataTFPDU"
+"PresentationContextAC"
+"DIMSE"
+"PresentationContextGenerator"
+"AAssociateRQPDU"
+"ImplementationUIDSub"
+"ULConnection"
+"PresentationContext"
+"QueryStudy"
+"MovePatientRootQuery"
+"CEchoMessages"
+"QueryFactory"
+"ULConnectionManager"
+"ULConnectionInfo"
+"MaximumLengthSub"
+"TransferSyntaxSub"
+"ARTIMTimer"
+"AbstractSyntax"
+"CFindMessages"
+"AsynchronousOperationsWindowSub"
+"ImplementationClassUIDSub"
+"UserInformation"
+"CMoveMessages"
+"PDUFactory"
+"CStoreMessages"
+"FindStudyRootQuery"
+"AAbortPDU"
+"BaseCompositeMessage"
+"ULActionAR"
+"AReleaseRPPDU"
+"ULTransitionTable"
+"PresentationDataValue"
+"BasePDU"
+"QuerySeries"
+"ULAction"
+"ULWritingCallback"
+"CompositeMessageFactory"
+"CommandDataSet"
+"FindPatientRootQuery"
 )
 
 def processonedir(dirname):
